@@ -18,14 +18,12 @@ from gtkmvc import View
 class MyView (View):
     """Glade-based view class.
 
-       The view is a window containing a button and a label. The label
-       shows the value of a counter contained in the model. Of course
-       the controller does the connection. Every time the button is
-       pressed, the counter will be incremented."""
-
-    def __init__(self, ctrl):
-        View.__init__(self, ctrl, 'pygtkmvc-example.glade')
-        return
+       The view is a window containing a button and a label. The
+       label shows the value of a counter contained in the
+       model. Of course the controller wil provide the
+       connection. Every time the button is pressed, the counter
+       will be incremented."""
+    glade = "pygtkmvc-example.glade"
 
     pass # end of class
 # ----------------------------------------------------------------------
