@@ -34,31 +34,19 @@ import gtk
 # observable property containing a map of integers
 
 class MyView (View):
-    def __init__(self, ctrl):
-        View.__init__(self, ctrl, "adapters.glade", "window3")
-        return
+    glade = "adapters.glade"
+    top = "window3"
     pass
 
-
 class MyModel (Model):
-    __properties__ = {
-        'box' : { 'en3' : 0,
-                  'lbl3' : 1,
-                  'sb3' : 2
-                  }
-        }
-    
-    def __init__(self):
-        Model.__init__(self)
-        return
+    box = { 'en3' : 0,
+            'lbl3' : 1,
+            'sb3' : 2 }
+    __observables__ = ("box",)
     pass
 
 import random
 class MyCtrl (Controller):
-    def __init__(self, m):
-        Controller.__init__(self, m)
-        return
-
     def register_adapters(self):
         a = StaticContainerAdapter(self.model, "box", value_error=myerr)
         a.connect_widget(map(lambda x: self.view[x], "en3 lbl3 sb3".split()), 
@@ -85,8 +73,8 @@ def myerr(adapt, name, val):
 
 
 m = MyModel()
-c = MyCtrl(m)
-v = MyView(c)
+v = MyView()
+c = MyCtrl(m,v)
 gtk.main()
 
 
