@@ -35,8 +35,8 @@ import gtk
 
 # hand-made view simply containing a text entry and a button
 class MyView (gtkmvc.View):
-    def __init__(self, ctrl):
-        gtkmvc.View.__init__(self, ctrl, register=False)
+    def __init__(self):
+        super(MyView,self).__init__()
 
         w = gtk.Window()
         e = gtk.Entry()
@@ -48,7 +48,6 @@ class MyView (gtkmvc.View):
         self['entry_text'] = e
         self['button'] = b
         self['window'] = w
-        ctrl.register_view(self)
         return
     pass # end of class
  #-----------------------------------------------------------
@@ -62,7 +61,6 @@ class MyCtrl (gtkmvc.Controller):
         return
 
     def register_view(self, view):
-        gtkmvc.Controller.register_view(self, view)
         view['button'].connect('clicked', self.on_button_clicked)
         view['window'].connect('delete-event', gtk.main_quit)
         return
@@ -76,16 +74,13 @@ class MyCtrl (gtkmvc.Controller):
  #-----------------------------------------------------------
 
 class MyModel (gtkmvc.Model):
-
-    __properties__ = {
-        'text' : "Ciao",
-        }
-
+    text = "Ciao"
+    __observables__ = ("text",)
     pass # end of class
  #-----------------------------------------------------------
 
 m = MyModel()
-c = MyCtrl(m)
-v = MyView(c)
+v = MyView()
+c = MyCtrl(m, v)
 
 gtk.main()
