@@ -63,30 +63,21 @@ class UserClass (observable.Observable):
 
 
 class MyView (View):
-    def __init__(self, ctrl):
-        View.__init__(self, ctrl, "adapters.glade", "window2")
-        return
+    glade = "adapters.glade"
+    top = "window2"
     pass
 
 
 class MyModel (Model):
-    __properties__ = {
-        'xx' : UserClass(10), 
-        }
-
-    def __init__(self):
-        Model.__init__(self)
-        return
+    xx = UserClass(10)
+    __observables__ = ("xx",)
     pass
 
 
 class MyCtrl (Controller):
-    def __init__(self, m):
-        Controller.__init__(self, m)
-        return
-
     def register_adapters(self):
-        a = UserClassAdapter(self.model, "xx", "get_x", "set_x", value_error=myerr)
+        a = UserClassAdapter(self.model, "xx", "get_x", "set_x",
+                             value_error=myerr)
         a.connect_widget(self.view["en2"])
         self.adapt(a)
         return
@@ -108,8 +99,8 @@ def myerr(adapt, name, val):
     return
 
 m = MyModel()
-c = MyCtrl(m)
-v = MyView(c)
+v = MyView()
+c = MyCtrl(m, v)
 
 m.xx.set_x(5)
 
