@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@irst.itc.it>
+#  Author: Roberto Cavada <cavada@fbk.eu>
 #
 #  Copyright (c) 2006 by Roberto Cavada
 #
@@ -18,8 +18,8 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author Roberto Cavada <cavada@irst.itc.it>.
-#  Please report bugs to <cavada@irst.itc.it>.
+#  or email to the author Roberto Cavada <cavada@fbk.eu>.
+#  Please report bugs to <cavada@fbk.eu>.
 
 
 import _importer
@@ -30,11 +30,12 @@ class MyModel (Model):
     """Our model contains a numeric counter and a numeric value that
     holds the value that the counter must be assigned to when we the
     model is reset"""
+    
+    counter = 0
+    reset_value = 0
 
-    __properties__ = {
-        'counter' : 0, 
-        'reset_value' : 0,
-        }
+    __observables__ = ('counter', 'reset_value')
+    
 
     def __init__(self):
         Model.__init__(self)
