@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@irst.itc.it>
+#  Author: Roberto Cavada <cavada@fbk.eu>
 #
 #  Copyright (c) 2006 by Roberto Cavada
 #
@@ -18,8 +18,8 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author Roberto Cavada <cavada@irst.itc.it>.
-#  Please report bugs to <cavada@irst.itc.it>.
+#  or email to the author Roberto Cavada <cavada@fbk.eu>.
+#  Please report bugs to <cavada@fbk.eu>.
 
 
 if __name__ == "__main__":
@@ -29,8 +29,8 @@ if __name__ == "__main__":
     from view import MyView
     
     m = MyModel()
-    c = MyCtrl(m)
-    v = MyView(c)
+    v = MyView()
+    c = MyCtrl(m, v)
 
     import gtk
     gtk.main()
