@@ -28,7 +28,7 @@ import time
 
 from gtkmvc.adapters.default import * 
 from gtkmvc.observer import Observer
-
+from gtkmvc import Model
 
 # ----------------------------------------------------------------------
 class Adapter (Observer):
@@ -88,6 +88,14 @@ class Adapter (Observer):
         self._connect_model(model)
         return
 
+    def get_property_name(self):
+        """Returns the property the adapter is conected to"""
+        return self._prop_name
+
+    def get_widget(self):
+        """Returns the widget the adapter is conected to"""
+        return self._wid
+    
     def connect_widget(self, wid,
                        getter=None, setter=None, 
                        signal=None, arg=None, update=True):
@@ -169,7 +177,7 @@ class Adapter (Observer):
             models = parts[:-1]
             for name in models:
                 model = getattr(model, name)
-                if not isinstance(model, gtkmvc.Model):
+                if not isinstance(model, Model):
                     raise TypeError("Attribute '" + name +
                                     "' was expected to be a Model, but found: " +
                                     str(model))
@@ -192,7 +200,8 @@ class Adapter (Observer):
         self._prop_name = prop
         
         # registration of model:
-        self.register_model(model)
+        self._model = model
+        self.observe_model(model)
         return
     
 
@@ -218,12 +227,12 @@ class Adapter (Observer):
     def _get_property(self):
         """Private method that returns the value currently stored
         into the property"""
-        return getattr(self.get_model(), self._prop_name)
+        return getattr(self._model, self._prop_name)
         #return self._prop # bug fix reported by A. Dentella
 
     def _set_property(self, val):
         """Private method that sets the value currently of the property."""
-        return setattr(self.get_model(), self._prop_name, val)
+        return setattr(self._model, self._prop_name, val)
 
     def _read_property(self, *args):
         """Returns the (possibly transformed) value that is stored
