@@ -28,10 +28,14 @@ import gtk
 import os
 
 class ProgenView (View):
-    GLADE_FILE = os.path.join(PROGEN_DIR, "progen.glade")
+    glade = os.path.join(PROGEN_DIR, "progen.glade")
 
-    def __init__(self, ctrl):
-        View.__init__(self, ctrl, self.GLADE_FILE)
+    def __init__(self):
+        super(ProgenView, self).__init__()
+        self.setup_widgets()
+        return
+
+    def setup_widgets(self):
         self['notebook_appl'].set_show_tabs(False)
         nb = self['notebook']
         nb.set_show_tabs(False)
